use std::ops::Not;

use bevy::prelude::*;
use itermore::IterArrayChunks;

use super::{
	display::{Display, RenderUpdate},
	physics::{Forces, Mass, Pos},
};

pub fn spawn_block(
	cmd: &mut Commands,
	rerender: &mut EventWriter<RenderUpdate>,
	pos: IVec2,
	display: (char, char),
	mass: usize,
) {
	cmd.spawn((Forces::zero(), Pos(pos), Mass(mass), Display(display)));
	rerender.send(RenderUpdate(pos));
}

pub fn str_to_struct(text: &str) -> Vec<(IVec2, (char, char), usize)> {
	text.lines()
		.enumerate()
		.flat_map(|(y, line)| {
			line.chars().array_chunks().enumerate().filter_map(move |(x, [l, r])| {
				(l == ' ' && r == ' ')
					.not()
					.then_some((IVec2::new(x as _, y as _), (l, r), mass_of((l, r))))
			})
		})
		.collect()
}

pub fn mass_of(tiles: (char, char)) -> usize {
	match tiles {
		('#', '#') => 100,
		('X', 'X') => 10,
		('[', ']') => 8,
		('(', ')') => 5,
		_ => 20,
	}
}

pub fn spawn_debug_map(mut cmd: Commands, mut rerender: EventWriter<RenderUpdate>) {
	let raw = "
        ()            
                      
      ##########  ()  
    ()##      ##      
      ##  []          
      ##      ##      
      ##########()    
                      
                      
";

	for (pos, display, mass) in str_to_struct(raw) {
		spawn_block(&mut cmd, &mut rerender, pos, display, mass);
	}
}
