use bevy::prelude::*;
use sysinfo::{CpuRefreshKind, RefreshKind, System};
use termion::cursor;

use super::player::Player;

pub struct MetricsPlugin;

#[derive(Debug, Resource)]
pub struct SysRes(System);

impl Plugin for MetricsPlugin {
	fn build(&self, app: &mut App) {
		let sys = System::new_with_specifics(RefreshKind::new().with_cpu(CpuRefreshKind::new().with_cpu_usage()));
		app.add_systems(Update, show_metrics).insert_resource(SysRes(sys));
	}
}

fn show_metrics(time: Res<Time>, mut sys: ResMut<SysRes>, players: Query<(), With<Player>>, entities: Query<Entity>) {
	let player_count = players.iter().count();
	let entity_count = entities.iter().count();
	let time_delta = time.delta_seconds();
	let cpu = sys.0.global_cpu_usage();
	sys.0.refresh_all();
	let up = cursor::Up(1);
	println!("  | ent {entity_count:2} | ply {player_count:2} | tick {time_delta:2.3} | cpu {cpu:2.1}{up}  ");
}
