#![allow(dead_code)]
#![allow(unstable_name_collisions)]

use std::time::Duration;

use bevy::{app::ScheduleRunnerPlugin, prelude::*, time::TimePlugin};
use lib_server::{
	display::DisplayPlugin, generation::GenerationPlugin, map, metrics::MetricsPlugin, net::NetPlugin,
	physics::PhysicsPlugin, player::PlayerPlugin,
};

mod common;
mod lib_server;

fn main() {
	App::new()
		// Core.
		.add_plugins(ScheduleRunnerPlugin::run_loop(Duration::from_millis(100)))
		.add_plugins(TimePlugin)
		// World.
		.add_plugins(PhysicsPlugin)
		.add_plugins(DisplayPlugin)
		.add_plugins(NetPlugin)
		.add_plugins(GenerationPlugin)
		// Content.
		.add_plugins(PlayerPlugin)
		// Debug.
		.add_plugins(MetricsPlugin)
		// Startup.
		.add_systems(Startup, map::spawn_debug_map)
		.run();
}
